==> python-dateparser-0.7.6-1-any.pkg.tar.xz: usr/lib/python3.8/site-packages/dateparser/data/date_translation_data/mk.py <==
# -*- coding: utf-8 -*-
info = {
    "name": "mk",
    "date_order": "DMY",
    "january": [
        "јануари",
        "јан"
    ],
    "february": [
        "февруари",
        "фев"
    ],
    "march": [
        "март",
        "мар"
    ],
    "april": [
        "април",
        "апр"
    ],
    "may": [
        "мај"
    ],
    "june": [
        "јуни",
        "јун"
    ],
    "july": [
        "јули",
        "јул"
    ],
    "august": [
        "август",
        "авг"
    ],
    "september": [
        "септември",
        "септ"
    ],
    "october": [
        "октомври",
        "окт"
    ],
    "november": [
        "ноември",
        "ноем"
    ],
    "december": [
        "декември",
        "дек"
    ],
    "monday": [
        "понеделник",
        "пон"
    ],
    "tuesday": [
        "вторник",
        "вто",
        "вт"
    ],
    "wednesday": [
        "среда",
        "сре"
    ],
    "thursday": [
        "четврток",
        "чет"
    ],
    "friday": [
        "петок",
        "пет"
    ],
    "saturday": [
        "сабота",
        "саб"
    ],
    "sunday": [
        "недела",
        "нед"
    ],
    "am": [
        "претпладне",
        "претпл"
    ],
    "pm": [
        "попладне",
        "попл"
    ],
    "year": [
        "година",
        "год"
    ],
    "month": [
        "месец",
        "мес"
    ],
    "week": [
        "недела",
        "сед"
    ],
    "day": [
        "ден"
    ],
    "hour": [
        "час"
    ],
    "minute": [
        "минута",
        "мин"
    ],
    "second": [
        "секунда",
        "сек"
    ],
    "relative-type": {
        "1 year ago": [
            "минатата година"
        ],
        "0 year ago": [
            "оваа година"
        ],
        "in 1 year": [
            "следната година"
        ],
        "1 month ago": [
            "минатиот месец"
        ],
        "0 month ago": [
            "овој месец"
        ],
        "in 1 month": [
            "следниот месец"
        ],
        "1 week ago": [
            "минатата седмица"
        ],
        "0 week ago": [
            "оваа седмица"
        ],
        "in 1 week": [
            "следната седмица"
        ],
        "1 day ago": [
            "вчера"
        ],
        "0 day ago": [
            "денес"
        ],
        "in 1 day": [
            "утре"
        ],
        "0 hour ago": [
            "часов"
        ],
        "0 minute ago": [
            "оваа минута"
        ],
        "0 second ago": [
            "сега"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "за (\\d+) година",
            "за (\\d+) години"
        ],
        "\\1 year ago": [
            "пред (\\d+) година",
            "пред (\\d+) години"
        ],
        "in \\1 month": [
            "за (\\d+) месец",
            "за (\\d+) месеци"
        ],
        "\\1 month ago": [
            "пред (\\d+) месец",
            "пред (\\d+) месеци"
        ],
        "in \\1 week": [
            "за (\\d+) седмица",
            "за (\\d+) седмици"
        ],
        "\\1 week ago": [
            "пред (\\d+) седмица",
            "пред (\\d+) седмици"
        ],
        "in \\1 day": [
            "за (\\d+) ден",
            "за (\\d+) дена"
        ],
        "\\1 day ago": [
            "пред (\\d+) ден",
            "пред (\\d+) дена"
        ],
        "in \\1 hour": [
            "за (\\d+) час",
            "за (\\d+) часа"
        ],
        "\\1 hour ago": [
            "пред (\\d+) час",
            "пред (\\d+) часа"
        ],
        "in \\1 minute": [
            "за (\\d+) минута",
            "за (\\d+) минути"
        ],
        "\\1 minute ago": [
            "пред (\\d+) минута",
            "пред (\\d+) минути"
        ],
        "in \\1 second": [
            "за (\\d+) секунда",
            "за (\\d+) секунди"
        ],
        "\\1 second ago": [
            "пред (\\d+) секунда",
            "пред (\\d+) секунди"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> python-dateparser-1.1.1-1-any.pkg.tar.xz: usr/lib/python3.10/site-packages/dateparser/data/date_translation_data/mk.py <==
info = {
    "name": "mk",
    "date_order": "DMY",
    "january": [
        "јан",
        "јануари"
    ],
    "february": [
        "фев",
        "февруари"
    ],
    "march": [
        "мар",
        "март"
    ],
    "april": [
        "апр",
        "април"
    ],
    "may": [
        "мај"
    ],
    "june": [
        "јун",
        "јуни"
    ],
    "july": [
        "јул",
        "јули"
    ],
    "august": [
        "авг",
        "август"
    ],
    "september": [
        "септ",
        "септември"
    ],
    "october": [
        "окт",
        "октомври"
    ],
    "november": [
        "ноем",
        "ноември"
    ],
    "december": [
        "дек",
        "декември"
    ],
    "monday": [
        "пон",
        "понеделник"
    ],
    "tuesday": [
        "вт",
        "вто",
        "вторник"
    ],
    "wednesday": [
        "сре",
        "среда"
    ],
    "thursday": [
        "чет",
        "четврток"
    ],
    "friday": [
        "пет",
        "петок"
    ],
    "saturday": [
        "саб",
        "сабота"
    ],
    "sunday": [
        "нед",
        "недела"
    ],
    "am": [
        "претпл",
        "претпладне"
    ],
    "pm": [
        "попл",
        "попладне"
    ],
    "year": [
        "год",
        "година"
    ],
    "month": [
        "мес",
        "месец"
    ],
    "week": [
        "недела",
        "сед"
    ],
    "day": [
        "ден"
    ],
    "hour": [
        "час"
    ],
    "minute": [
        "мин",
        "минута"
    ],
    "second": [
        "сек",
        "секунда"
    ],
    "relative-type": {
        "0 day ago": [
            "денес"
        ],
        "0 hour ago": [
            "часов"
        ],
        "0 minute ago": [
            "оваа минута"
        ],
        "0 month ago": [
            "овој месец"
        ],
        "0 second ago": [
            "сега"
        ],
        "0 week ago": [
            "оваа седмица"
        ],
        "0 year ago": [
            "оваа година"
        ],
        "1 day ago": [
            "вчера"
        ],
        "1 month ago": [
            "минатиот месец"
        ],
        "1 week ago": [
            "минатата седмица"
        ],
        "1 year ago": [
            "минатата година"
        ],
        "in 1 day": [
            "утре"
        ],
        "in 1 month": [
            "следниот месец"
        ],
        "in 1 week": [
            "следната седмица"
        ],
        "in 1 year": [
            "следната година"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "пред (\\d+) ден",
            "пред (\\d+) дена"
        ],
        "\\1 hour ago": [
            "пред (\\d+) час",
            "пред (\\d+) часа"
        ],
        "\\1 minute ago": [
            "пред (\\d+) минута",
            "пред (\\d+) минути"
        ],
        "\\1 month ago": [
            "пред (\\d+) месец",
            "пред (\\d+) месеци"
        ],
        "\\1 second ago": [
            "пред (\\d+) секунда",
            "пред (\\d+) секунди"
        ],
        "\\1 week ago": [
            "пред (\\d+) седмица",
            "пред (\\d+) седмици"
        ],
        "\\1 year ago": [
            "пред (\\d+) година",
            "пред (\\d+) години"
        ],
        "in \\1 day": [
            "за (\\d+) ден",
            "за (\\d+) дена"
        ],
        "in \\1 hour": [
            "за (\\d+) час",
            "за (\\d+) часа"
        ],
        "in \\1 minute": [
            "за (\\d+) минута",
            "за (\\d+) минути"
        ],
        "in \\1 month": [
            "за (\\d+) месец",
            "за (\\d+) месеци"
        ],
        "in \\1 second": [
            "за (\\d+) секунда",
            "за (\\d+) секунди"
        ],
        "in \\1 week": [
            "за (\\d+) седмица",
            "за (\\d+) седмици"
        ],
        "in \\1 year": [
            "за (\\d+) година",
            "за (\\d+) години"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
